# desklank

Text-mode peer-to-peer encrypted communication utilizing LANK protocol and
DeskApp framework.

## Installation

It is easy to install desklank using pip:
```
pip install desklank
```

## Usage

Once installed, simply run the `desklank` command from any terminal.

## Author

Created by Shawn A. Wilson [lannocc@yahoo.com] aka LANNOCC.

